/* worker_commands.h
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2001 Ralf Hoffmann.
 * You can contact me at: ralf.hoffmann@epost.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: worker_commands.h,v 1.23 2003/05/04 01:35:31 ralf Exp $ */

#ifndef WORKER_COMMANDS_H
#define WORKER_COMMANDS_H

#include "worker.h"
#include "basic_actions.h"
#include "cursorops.h"
#include "copyop.h"
#include "deleteop.h"
#include "normalops.h"
#include "reloadop.h"
#include "makedirop.h"
#include "ownop.h"
#include "renameop.h"
#include "dirsizeop.h"
#include "simddop.h"
#include "startprogop.h"
#include "searchentryop.h"
#include "enterpathop.h"
#include "scrolllisterop.h"
#include "createsymlinkop.h"
#include "changesymlinkop.h"
#include "chmodop.h"
#include "togglelistermodeop.h"
#include "setsortmodeop.h"
#include "setfilterop.h"
#include "shortkeyfromlistop.h"
#include "chownop.h"
#include "scriptop.h"
#include "showdircacheop.h"

#include "listermode.h"
#include "normalmode.h"
#include "showimagemode.h"
#include "informationmode.h"

#endif
